@@ -1,7 +1,7 @@
 """Custom jsonschema.IValidator class and validator functions.
 """
 
-from collections import Iterable
+from collections.abc import Iterable
 import io
 from itertools import chain
 import os
@@ -17,8 +17,8 @@ from six import iteritems, string_types, text_type
 from . import output
 from .errors import (NoJSONFileFoundError, SchemaError, SchemaInvalidError,
                      ValidationError, pretty_error)
-from .util import (DEFAULT_VER, ValidationOptions, check_spec,
-                   clear_requests_cache, init_requests_cache)
+from .util import (DEFAULT_VER, ValidationOptions, clear_requests_cache,
+                   init_requests_cache)
 from .v20 import musts as musts20
 from .v20 import shoulds as shoulds20
 from .v21 import musts as musts21
@@ -651,6 +651,14 @@ def _get_error_generator(type, obj, schema_dir=None, version=DEFAULT_VER, defaul
                 "minProperties": 1
             }
         }
+    elif type == 'bundle':
+        # Validate against schemas for specific objects later
+        schema['properties']['objects'] = {
+            "objects": {
+                "type": "array",
+                "minItems": 1
+            }
+        }
 
     # Don't use custom validator; only check schemas, no additional checks
     validator = load_validator(schema_path, schema)
@@ -688,7 +696,7 @@ def _get_shoulds(options):
         return shoulds21.list_shoulds(options)
 
 
-def _schema_validate(sdo, options):
+def _schema_validate(obj, options, bundle_version=None):
     """Set up validation of a single STIX object against its type's schema.
     This does no actual validation; it just returns generators which must be
     iterated to trigger the actual generation.
@@ -698,12 +706,20 @@ def _schema_validate(sdo, options):
 
     Do not call this function directly; use validate_instance() instead, as it
     calls this one. This function does not perform any custom checks.
+
+    Args:
+        obj: STIX object to validate.
+        options: ValidationOptions instance with validation options for this
+            validation run, including the STIX spec version.
+        bundle_version: STIX version of the bundle containing this object, or
+            None if the object is not inside a bundle or the bundle has no
+            spec_version property.
     """
     error_gens = []
 
-    if 'id' in sdo:
+    if 'id' in obj:
         try:
-            error_prefix = sdo['id'] + ": "
+            error_prefix = obj['id'] + ": "
         except TypeError:
             error_prefix = 'unidentifiable object: '
     else:
@@ -711,40 +727,58 @@ def _schema_validate(sdo, options):
 
     if options.version:
         version = options.version
-    elif options.version is None and 'spec_version' in sdo:
-        version = sdo['spec_version']
+    elif options.version is None and 'spec_version' in obj:
+        version = obj['spec_version']
     else:
         version = DEFAULT_VER
 
+    if bundle_version == '2.0':
+        version = bundle_version
+
+    # Allow 2.0 objects in 2.1+ bundles (2.1 SCOs don't have 'created')
+    _20_in_21_bundle = (bundle_version == '2.1' and 'spec_version' not in obj and
+                        'created' in obj)
+    if _20_in_21_bundle:
+        version = '2.0'
+        output.info("%sno spec_version so treated as a 2.0 object in a 2.1 bundle."
+                    % error_prefix)
+
     options.set_check_codes(version)
 
+    core_schema = 'core'
+    # Check for custom 2.1+ SCO
+    if (version > '2.0' and all(p in obj for p in ['type', 'id']) and
+            all(p not in obj for p in ['created', 'modified']) and
+            not obj['type'] == 'marking-definition'):
+        core_schema = 'cyber-observable-core'
+
     # Get validator for built-in schema
-    base_sdo_errors = _get_error_generator(sdo['type'], sdo, version=version)
+    base_sdo_errors = _get_error_generator(obj['type'], obj, version=version, default=core_schema)
     if base_sdo_errors:
         error_gens.append((base_sdo_errors, error_prefix))
 
     # Get validator for any user-supplied schema
     if options.schema_dir:
-        custom_sdo_errors = _get_error_generator(sdo['type'], sdo, options.schema_dir)
+        custom_sdo_errors = _get_error_generator(obj['type'], obj, options.schema_dir, default=core_schema)
         if custom_sdo_errors:
             error_gens.append((custom_sdo_errors, error_prefix))
 
     # Validate each cyber observable object separately
-    if sdo['type'] == 'observed-data' and 'objects' in sdo:
+    if obj['type'] == 'observed-data' and 'objects' in obj:
         # Check if observed data property is in dictionary format
-        if not isinstance(sdo['objects'], dict):
+        if not isinstance(obj['objects'], dict):
             error_gens.append(([schema_exceptions.ValidationError("Observed Data objects must be in dict format.", error_prefix)],
                               error_prefix))
             return error_gens
 
-        for key, obj in iteritems(sdo['objects']):
-            if 'type' not in obj:
+        for key, val in iteritems(obj['objects']):
+            if 'type' not in val:
                 error_gens.append(([schema_exceptions.ValidationError("Observable object must contain a 'type' property.", error_prefix)],
                                    error_prefix + 'object \'' + key + '\': '))
                 continue
             # Get validator for built-in schemas
-            base_obs_errors = _get_error_generator(obj['type'],
-                                                   obj,
+            base_obs_errors = _get_error_generator(val['type'],
+                                                   val,
                                                    None,
                                                    version,
                                                    'cyber-observable-core')
@@ -754,8 +788,8 @@ def _schema_validate(sdo, options):
 
             # Get validator for any user-supplied schema
             if options.schema_dir:
-                custom_obs_errors = _get_error_generator(obj['type'],
-                                                         obj,
+                custom_obs_errors = _get_error_generator(val['type'],
+                                                         val,
                                                          options.schema_dir,
                                                          version,
                                                          'cyber-observable-core')
@@ -766,6 +800,35 @@ def _schema_validate(sdo, options):
     return error_gens
 
 
+def _schema_validate_bundle(instance, options):
+    errors = []
+    version = options.version
+    if version is None and 'spec_version' in instance:
+        version = instance['spec_version']
+
+    warnings = []
+    if version:
+        if 'spec_version' in instance:
+            if instance['spec_version'] != version:
+                warnings.append(instance['id'] + ": spec_version mismatch with supplied"
+                                " option. Treating as {} content.".format(version))
+        if 'objects' in instance:
+            for obj in instance['objects']:
+                if 'spec_version' in obj:
+                    if obj['spec_version'] != version:
+                        warnings.append(obj['id'] + ": spec_version mismatch with supplied"
+                                        " option. Treating as {} content.".format(version))
+
+    bundle_version = instance.get('spec_version', '2.1')
+    # Validate each object in a bundle separately
+    for sdo in instance.get('objects', []):
+        if 'type' not in sdo:
+            raise ValidationError("Each object in bundle must have a 'type' property.")
+        errors += _schema_validate(sdo, options, bundle_version)
+
+    return errors, warnings
+
+
 def validate_instance(instance, options=None):
     """Perform STIX JSON Schema validation against STIX input.
 
@@ -789,19 +852,13 @@ def validate_instance(instance, options=None):
         options = ValidationOptions()
 
     error_gens = []
+    spec_warnings = []
 
     # Schema validation
     error_gens += _schema_validate(instance, options)
     if instance['type'] == 'bundle' and 'objects' in instance:
-        if options.version is None and 'spec_version' in instance:
-            options.version = instance['spec_version']
-        # Validate each object in a bundle separately
-        for sdo in instance['objects']:
-            if 'type' not in sdo:
-                raise ValidationError("Each object in bundle must have a 'type' property.")
-            error_gens += _schema_validate(sdo, options)
-
-    spec_warnings = check_spec(instance, options)
+        schema_errors, spec_warnings = _schema_validate_bundle(instance, options)
+        error_gens += schema_errors
 
     # Custom validation
     must_checks = _get_musts(options)
